@@ -13,21 +13,34 @@
 from functools import cmp_to_key
 from typing import Any
 
-from jdmn.feel.lib.Types import BOOLEAN, LIST, INT
+from jdmn.feel.lib.Types import BOOLEAN, LIST, INTEGER
 from jdmn.runtime.LambdaExpression import LambdaExpression
 
 
 class DefaultListLib:
-    def listContains(self, list_: LIST, element: Any) -> BOOLEAN:
+    @staticmethod
+    def listContains(list_: LIST, element: Any) -> BOOLEAN:
         if list_ is None:
             return None
 
         return element in list_
 
-    def append(self, list_: LIST, *items) -> LIST:
-        raise Exception("Not supported yet")
+    @staticmethod
+    def append(list_: LIST, *items) -> LIST:
+        result = []
+        if list_ is not None:
+            result.extend(list_)
+        if items is not None:
+            for item in items:
+                result.append(item)
+        else:
+            result.append(None)
+        return result
+
+    def sublist(self, list_: LIST, position: INTEGER, length: INTEGER = None) -> LIST:
+        if position is None:
+            return None
 
-    def sublist(self, list_: LIST, position: INT, length: INT = None) -> LIST:
         result = []
         if list_ is None or self.isOutOfBounds(list_, position):
             return result
@@ -35,30 +48,61 @@ class DefaultListLib:
             startIndex = len(list_) + position
         else:
             startIndex = position - 1
-        endIndex = startIndex + length
+        endIndex = len(list_) if length is None else startIndex + length
         return list_[startIndex: endIndex]
 
-    def concatenate(self, *lists) -> LIST:
+    @staticmethod
+    def concatenate(*lists) -> LIST:
         result = []
         if lists is not None:
             for list_ in lists:
                 result.extend(list_)
         return result
 
-    def insertBefore(self, list_: LIST, position: INT, newItem: Any) -> LIST:
-        raise Exception("Not supported yet")
+    def insertBefore(self, list_: LIST, position: INTEGER, newItem: Any) -> LIST:
+        result = []
+        if list_ is not None:
+            result.extend(list_)
+        if self.isOutOfBounds(result, position):
+            return result
+        if position < 0:
+            position = len(result) + position
+        else:
+            position = position - 1
+        result.insert(position, newItem)
+        return result
 
-    def remove(self, list_: LIST, position: INT) -> LIST:
-        raise Exception("Not supported yet")
+    @staticmethod
+    def remove(list_: LIST, position: INTEGER) -> LIST:
+        result = []
+        if list_ is not None:
+            result.extend(list_)
+        result.pop(position - 1)
+        return result
 
-    def reverse(self, list_: LIST) -> LIST:
-        raise Exception("Not supported yet")
+    @staticmethod
+    def reverse(list_: LIST) -> LIST:
+        result = []
+        if list_ is not None:
+            result = list_.copy()
+            result.reverse()
+        return result
 
     def union(self, *lists) -> LIST:
-        raise Exception("Not supported yet")
+        result = []
+        if lists is not None:
+            for list_ in lists:
+                result.extend(list_)
+        return self.distinctValues(result)
 
-    def distinctValues(self, list1: LIST) -> LIST:
-        raise Exception("Not supported yet")
+    @staticmethod
+    def distinctValues(list1: LIST) -> LIST:
+        result = []
+        if list1 is not None:
+            for element in list1:
+                if element not in result:
+                    result.append(element)
+        return result
 
     def flatten(self, list1: LIST) -> LIST:
         if list1 is None:
@@ -75,13 +119,18 @@ class DefaultListLib:
                 else:
                     result.append(obj)
 
-    def sort(self, list_: LIST, precedes: LambdaExpression) -> LIST:
+    @staticmethod
+    def sort(list_: LIST, precedes: LambdaExpression) -> LIST:
         clone = []
         clone.extend(list_)
         clone.sort(key=cmp_to_key(lambda o1, o2: -1 if precedes.apply(o1, o2) else (0 if o1 == o2 else 1)))
         return clone
 
-    def isOutOfBounds(self, list_: LIST, position: int) -> bool:
+    @staticmethod
+    def isOutOfBounds(list_: LIST, position: INTEGER) -> bool:
+        if position is None:
+            return False
+
         length = len(list_)
         if position < 0:
             return not (-length <= position)
